@@ -4,6 +4,6 @@ import { simpleGet, simplePost, simplePut } from '@tamanu/shared/utils/crudHelpe
 
 export const familyHistory = express.Router();
 
-familyHistory.get('/:id', simpleGet('PatientFamilyHistory'));
+familyHistory.get('/:id', simpleGet('PatientFamilyHistory', { auditAccess: true }));
 familyHistory.put('/:id', simplePut('PatientFamilyHistory'));
 familyHistory.post('/$', simplePost('PatientFamilyHistory'));
